import React from 'react';

type OtherIcon = string & {
    materialIcon?: any;
};
type IconStyles = 'account_circle' | 'home' | 'menu' | 'menu_open' | 'monitoring' | 'palette' | 'info' | 'search' | 'cancel' | 'login' | 'logout' | 'add' | 'remove' | 'close' | 'list' | 'construction' | 'work' | 'arrow_back' | 'arrow_forward' | OtherIcon;
type IconColors = 'primary' | 'on-primary-container' | 'on-surface-variant';

interface IconProps {
    icon: IconStyles;
    color?: IconColors;
    onClick?: Function;
}
declare function Icon(props: IconProps): React.JSX.Element;

type ButtonVariants = 'filled' | 'elevated' | 'tonal' | 'outlined' | 'text' | 'title';

interface ButtonProps extends React.HTMLProps<HTMLButtonElement> {
    text: string;
    variant?: ButtonVariants;
    icon?: IconStyles;
    iconOnly?: boolean;
    type?: 'button' | 'submit' | 'reset';
}
declare const Button: React.ForwardRefExoticComponent<Omit<ButtonProps, "ref"> & React.RefAttributes<HTMLButtonElement>>;

type DialogSizes = 'small' | 'medium' | 'large';

interface DialogProps extends React.HTMLProps<HTMLDivElement> {
    open: boolean;
    modalSize: DialogSizes;
    innerProps?: Partial<React.HTMLProps<HTMLDivElement>>;
}
declare const Dialog: React.ForwardRefExoticComponent<Omit<DialogProps, "ref"> & React.RefAttributes<HTMLDivElement>>;

interface DialogContentProps {
    children: React.ReactNode;
}
declare function DialogContent(props: DialogContentProps): React.JSX.Element;

interface DialogFooterProps {
    children: React.ReactNode;
}
declare function DialogFooter(props: DialogFooterProps): React.JSX.Element;

interface DialogHeaderProps {
    children: React.ReactNode;
}
declare function DialogHeader(props: DialogHeaderProps): React.JSX.Element;

interface DrawerProps {
    isOpen: boolean;
    handleCloseDrawer: React.MouseEventHandler;
    drawerContentBottom?: JSX.Element;
    drawerContentTop?: JSX.Element;
}
declare function Drawer(props: DrawerProps): React.JSX.Element;

interface DrawerItemProps {
    icon: IconStyles;
    onClick: Function;
    label?: string;
    match?: boolean;
}
declare function DrawerItem(props: DrawerItemProps): React.JSX.Element;

type LoadingSpinnerSizes = 'small' | 'large';

interface LoadingSpinnerProps {
    size: LoadingSpinnerSizes;
}
declare function LoadingSpinner(props: LoadingSpinnerProps): React.JSX.Element;

interface SideNavProps {
    topSection?: JSX.Element;
    bottomSection?: JSX.Element;
}
declare function SideNav(props: SideNavProps): React.JSX.Element;

interface SideNavItemProps {
    icon: IconStyles;
    onClick: Function;
    label?: string;
    match?: boolean;
}
declare function SideNavItem(props: SideNavItemProps): React.JSX.Element;

type TextInputStyles = 'filled' | 'outlined';
type TextInputColors = 'surface' | 'tinted-surface';

interface TextInputProps extends React.HTMLProps<HTMLInputElement> {
    label: string;
    inputStyle: TextInputStyles;
    background: TextInputColors;
    icon?: IconStyles;
}
declare const TextInput: React.ForwardRefExoticComponent<Omit<TextInputProps, "ref"> & React.RefAttributes<HTMLInputElement>>;

interface TopNavProps {
    leftSection?: JSX.Element;
    rightSection?: JSX.Element;
}
declare function TopNav(props: TopNavProps): React.JSX.Element;

interface TopNavItemProps {
    icon: IconStyles;
    onClick: Function;
    label?: string;
    match?: boolean;
}
declare function TopNavItem(props: TopNavItemProps): React.JSX.Element;

export { Button, ButtonVariants, Dialog, DialogContent, DialogFooter, DialogHeader, Drawer, DrawerItem, Icon, IconColors, IconStyles, LoadingSpinner, LoadingSpinnerSizes, SideNav, SideNavItem, TextInput, TopNav, TopNavItem };
